=======
lumflux
=======


.. image:: https://img.shields.io/pypi/v/lumflux.svg
        :target: https://pypi.python.org/pypi/lumflux

.. image:: https://img.shields.io/travis/Jhsmit/lumflux.svg
        :target: https://travis-ci.com/Jhsmit/lumflux

.. image:: https://readthedocs.org/projects/lumflux/badge/?version=latest
        :target: https://lumflux.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


Illuminating data web applications.


* Free software: MIT license
* Documentation: https://lumflux.readthedocs.io.

About
-----

Lumflux illuminates your path towards developing interactive web applications.

It is based on `panel <https://github.com/holoviz/panel>`_ and inspired by `lumen <https://github.com/holoviz/lumen>`_.

LumFlux was originally developed for the PyHDX web application (`GitHub <https://github.com/Jhsmit/PyHDX>`_, `web application <http://pyhdx.jhsmit.org/>`_)

The project is in early alpha but in a somewhat working state. Have a look in the `examples` directory to get started. API is extremely likely to change.  

Features
--------

* TODO

